keyring

package
v1.2.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2026 License: Apache-2.0 Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Delete

func Delete(serverURL string) error

Delete removes the stored token for the given Bitbucket server URL. Returns nil if no entry was found.

func Get

func Get(serverURL string) (string, error)

Get retrieves the stored token for the given Bitbucket server URL. Returns ("", nil) if no credential is found.

func Set

func Set(serverURL, token string) error

Set stores a token for the given Bitbucket server URL in the OS keychain.

Types

This section is empty.

Jump to