logging

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 12, 2026 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Verbose bool

Verbose controls whether debug output is written to stderr.

Functions

func Debugf

func Debugf(format string, args ...any)

Debugf writes a formatted line to stderr when verbose mode is active.

Types

type Transport

type Transport struct {
	Next http.RoundTripper
}

Transport is an http.RoundTripper that logs requests and responses when verbose mode is active.

func (*Transport) RoundTrip

func (t *Transport) RoundTrip(req *http.Request) (*http.Response, error)

Jump to